#!/bin/csh

# c-shell script to calculate daily anomaly

# !!!!!! What should be modified !!!!!!
# HHH  : home directory
# var  : name of data
# XXX  : number of grid in longitude
# YYY  : number of grid in latitude
# TTT  : number of total time (in day)
# SSS  : number(in julian) of the first day in the first year
#  (e.g. SSS should be 4 if the data starts from 4th of January)
# DDD  : number of days per 1 year (for models using 360 day calendar)
# EEE  : number(in julian) of the last day in the last year
# BYY  : first year (e.g. 1979)
# EYY  : last year (e.g. 2005)
# LYR  : whether the data has leap year or not
#  (e.g. 1 : leap year, 0 : no leap year)
# LNX  : whether the machine is linux or not
#  This is for the record length problem.
#  (e.g. 4 : linux machine, 1 : other machine)
# MMM  : missing value
# PPP  : period of data
# !!!!!! What should be modified !!!!!!

 setenv HHH /jdata4/cdl/kim/msd

 foreach var ( olr_av u850_n1 u200_n1 )

 setenv XXX 144
 setenv YYY 73
 setenv TTT 9862
 setenv SSS 1
 setenv DDD 365
 setenv EEE 365
 setenv BYY 1979
 setenv EYY 2005
 setenv LYR 1
 setenv LNX 1
 setenv MMM -999.
 setenv PPP 19790101_20051231

 cd ${HHH}/level_1/$var

 mkdir -p src/ano
 cd src/ano

 cp -f ${HHH}/level_1/sample/ano/ano.f90.sample .

 sed "s#homedir#$HHH#g"           ano.f90.sample > tmp1
 sed "s/variable/$var/g"                    tmp1 > tmp2
 sed "s/num_x/$XXX/g"                       tmp2 > tmp1
 sed "s/num_y/$YYY/g"                       tmp1 > tmp2 
 sed "s/num_t/$TTT/g"                       tmp2 > tmp1 
 sed "s/num_s/$SSS/g"                       tmp1 > tmp2 
 sed "s/num_d/$DDD/g"                       tmp2 > tmp1 
 sed "s/num_e/$EEE/g"                       tmp1 > tmp2 
 sed "s/beg_y/$BYY/g"                       tmp2 > tmp1 
 sed "s/end_y/$EYY/g"                       tmp1 > tmp2 
 sed "s/leap_year/$LYR/g"                   tmp2 > tmp1 
 sed "s/linux_recl/$LNX/g"                  tmp1 > tmp2 
 sed "s/missing/$MMM/g"                     tmp2 > tmp1 
 sed "s/period/$PPP/g"                      tmp1 > ano.f90
 endif

f90 ano.f90
a.out
rm -f a.out

 cd $HHH/level_1/$var/data

 sed "s/daily/daily.clim/g" daily.$PPP.ctl > daily.clim.$PPP.ctl
 sed "s/daily/daily.anom/g" daily.$PPP.ctl > daily.anom.$PPP.ctl
 
 end

