#!/bin/csh

# c-shell script to calculate variance using
# anomaly and filtered data

# !!!!!! What should be modified !!!!!!
# HHH  : home directory
# var  : name of data
# XXX  : number of grid in longitude
# YYY  : number of grid in latitude
# TTT  : number of total time (in day)
# SSS  : number(in julian) of the first day in the first year
#  (e.g. SSS should be 4 if the data starts from 4th of January)
# DDD  : number of days per 1 year (for models using 360 day calendar)
# EEE  : number(in julian) of the last day in the last year
# BYY  : first year (e.g. 1979)
# EYY  : last year (e.g. 2005)
# LYR  : whether the data has leap year or not
#  (e.g. 1 : leap year, 0 : no leap year)
# LNX  : whether the machine is linux or not
#  This is for the record length problem.
#  (e.g. 4 : linux machine, 1 : other machine)
# MMM  : missing value
# PPP  : period of data

# for ctl file
# BLO  : starting longitude
# BLA  : starting latitude
# DLO  : delta longitude
# DLA  : delta latitude
# !!!!!! What should be modified !!!!!!

 setenv HHH /jdata4/cdl/kim/msd

 foreach var ( olr_av u850_n1 u200_n1 )

 setenv XXX 144
 setenv YYY 73
 setenv TTT 9862
 setenv SSS 1
 setenv EEE 365
 setenv DDD 365
 setenv BYY 1979
 setenv EYY 2005
 setenv LYR 1
 setenv LNX 1
 setenv MMM -999.
 setenv PPP 19790101_20051231

# for ctl file
 setenv BLO 0.0
 setenv BLA -90.0
 setenv DLO 2.5
 setenv DLA 2.5

 cd $HHH/level_1/$var

# output directory
 mkdir -p var

# source directory
 mkdir -p src/var
 cd src/var

 cp -f $HHH/level_1/sample/var/var.f90.sample .

 sed "s#homedir#$HHH#g"           var.f90.sample > tmp1
 sed "s/variable/$var/g"                    tmp1 > tmp2
 sed "s/num_x/$XXX/g"                       tmp2 > tmp1
 sed "s/num_y/$YYY/g"                       tmp1 > tmp2
 sed "s/num_t/$TTT/g"                       tmp2 > tmp1
 sed "s/num_s/$SSS/g"                       tmp1 > tmp2
 sed "s/num_e/$EEE/g"                       tmp2 > tmp1
 sed "s/num_d/$DDD/g"                       tmp1 > tmp2
 sed "s/beg_y/$BYY/g"                       tmp2 > tmp1
 sed "s/end_y/$EYY/g"                       tmp1 > tmp2
 sed "s/leap_year/$LYR/g"                   tmp2 > tmp1
 sed "s/linux_recl/$LNX/g"                  tmp1 > tmp2
 sed "s/missing/$MMM/g"                     tmp2 > tmp1
 sed "s/period/$PPP/g"                      tmp1 > var.f90

f90 var.f90
a.out
rm -f a.out
 
 cd $HHH/level_1/$var/var

 cp -f $HHH/level_1/sample/var/var.ctl.sample .

 foreach dd (raw fil)
 foreach ss (all sum win)

 sed "s/data/$dd/g"   var.ctl.sample > tmp1
 sed "s/num_x/$XXX/g"           tmp1 > tmp2
 sed "s/num_y/$YYY/g"           tmp2 > tmp1
 sed "s/beg_lon/$BLO/g"         tmp1 > tmp2
 sed "s/beg_lat/$BLA/g"         tmp2 > tmp1
 sed "s/del_lon/$DLO/g"         tmp1 > tmp2
 sed "s/del_lat/$DLA/g"         tmp2 > tmp1
 sed "s/missing/$MMM/g"         tmp1 > tmp2
 sed "s/season/$ss/g"           tmp2 > $dd.$ss.ctl

 end
 end

# foreach var
 end

