#!/bin/csh

# c-shell script to plot ceof figures
# 1. CEOFs
# 2. percentage variance
# 3. lag corr. bet. PC1 and PC2
# 4. cross spectra bet. PC1 and PC2

# !!!!!! What should be modified !!!!!!
# HHH  : home directory
# TVA  : title
# TSE  : title (season)
# SN1, SN2 : sign of PCs (for lag corr.)
# MOR  : order of modes
#  (e.g. 1: 1 -> 2, 2: 2 -> 1)
# PPP  : period
# YRA  : y-range (for power spectra)
# YIN  : y-interval (for power spectra)
# !!!!!! What should be modified !!!!!!

 setenv HHH /jdata4/cdl/kim/msd

 foreach var ( ceof )

  setenv TTT 9862
  setenv TVA 'Combined EOF'
  setenv TSE 'All season'
  setenv SN1 1
  setenv SN2 -1
  setenv MOR 1
  setenv PPP 1979-2005
 
  setenv YRA 4
  setenv YIN 0.5

# file copy
 cd $HHH/level_2/$var
 cp -f $HHH/level_2/sample/ceof/ceof.gs.sample .

 sed "s#homedir#$HHH#g"             ceof.gs.sample > tmp1
 sed "s/title_sea/$TSE/g"                     tmp1 > tmp2
 sed "s/title_var/$TVA/g"                     tmp2 > tmp1
 sed "s/n_time/$TTT/g"                        tmp1 > tmp2
 sed "s/e1/$SN1*ev1/g"                        tmp2 > tmp1
 sed "s/e2/$SN2*ev2/g"                        tmp1 > tmp2
 sed "s/mode_order/$MOR/g"                    tmp2 > tmp1
 sed "s/period/$PPP/g"                        tmp1 > ceof.gs

grads -pbc << EOF
ceof
EOF

# percentage variance
 cp -f $HHH/level_2/sample/ceof/pct.gs.sample .
 sed "s/title_sea/$TSE/g"                 pct.gs.sample > tmp2
 sed "s/title_var/$TVA/g"                          tmp2 > pct.gs

grads -lbc << EOF
pct
EOF

# pcl
 cp -f $HHH/level_2/sample/ceof/pcl.gs.sample .

 sed "s#homedir#$HHH#g"                   pcl.gs.sample > tmp1
 sed "s/variable/$var/g"                           tmp1 > tmp2
 sed "s/title_sea/$TSE/g"                          tmp2 > tmp1
 sed "s/title_var/$TVA/g"                          tmp1 > pcl.gs

grads -lbc << EOF
pcl
EOF

# sp256
 cp -f $HHH/level_2/sample/ceof/power.gs.sample .
 cp -f $HHH/level_2/sample/ceof/power.dummy .
 cp -f $HHH/level_2/sample/ceof/power.dummy.ctl .

 foreach exp ( 1 2 )
  sed "s/title_sea/$TSE/g"           power.gs.sample > tmp1
  sed "s/number/$exp/g"                         tmp1 > tmp2
  sed "s/y_ran/$YRA/g"                          tmp2 > tmp1
  sed "s/y_int/$YIN/g"                          tmp1 > power.gs

grads -lbc << EOF
power.gs sp256.ts0$exp
EOF

 end

# crsp
 cp -f $HHH/level_2/sample/ceof/crsp.gs.sample .
 cp -f $HHH/level_2/sample/ceof/power.dummy .
 cp -f $HHH/level_2/sample/ceof/power.dummy.ctl .

 sed "s/title_sea/$TSE/g"                crsp.gs.sample > power.gs

grads -lbc << EOF
power.gs crsp
EOF

# copy gif
 mkdir -p $HHH/level_2/fig/ceof
 cp -f ceof.gif $HHH/level_2/fig/ceof/.
 cp -f pct.gif $HHH/level_2/fig/ceof/.
 cp -f pcl.gif $HHH/level_2/fig/ceof/.
 cp -f sp256.*.gif $HHH/level_2/fig/ceof/.
 cp -f crsp.gif $HHH/level_2/fig/ceof/.

 end
# foreach var
