#!/bin/csh

# c-shell script to plot MJO life-cycle composite
# seasonally stratified

# !!!!!! What should be modified !!!!!!
# HHH  : home directory
# ONL  : name of olr data
# MJO  : variable (e.g. OLR, PRCP)
# TVV  : data source
# CLV  : contour levels
# CLO  : colors for shading
# OPT  : option number for writing unit
# ( 1: doesn't have order, 2: has order )
# UN1  : unit (e.g. W m)
# OR1  : order (e.g. -2)
# TSEA : title (season)
# !!!!!! What should be modified !!!!!!

 setenv HHH /jdata4/cdl/kim/msd

 setenv ONM olr_av

 foreach var ( sst_tmi sst_oi evap_e evap_n1 evap_oa ssr_is ssr_ge )

# variable

 if ( $var == 'sst_tmi' ) then
  setenv MJO SST
  setenv TVV TMI
 endif
 if ( $var == 'sst_oi' ) then
  setenv MJO SST
  setenv TVV OISST
 endif
 if ( $var == 'evap_e' ) then
  setenv MJO EVAP
  setenv TVV ERA40
 endif
 if ( $var == 'evap_n1' ) then
  setenv MJO EVAP
  setenv TVV NCEP1
 endif
 if ( $var == 'evap_oa' ) then
  setenv MJO EVAP
  setenv TVV OAflux
 endif
 if ( $var == 'ssr_is' ) then
  setenv MJO NSSR
  setenv TVV ISCCP-FD
 endif
 if ( $var == 'ssr_ge' ) then
  setenv MJO NSSR
  setenv TVV GEWEX-SRB
 endif

 if ( $MJO == 'SST' ) then
  setenv OPT 1
  setenv LLL '-0.4 -0.35 -0.3 -0.25 -0.2 -0.15 -0.1 -0.05 0.05 0.1 0.15 0.2 0.25 0.3 0.35 0.4'
  setenv CCC '33 34 35 36 37 38 39 40 0 41 42 43 44 45 46 47 48'
  setenv UUU K
  setenv ODR 1
  setenv FAC 1
 else if ( $var == 'EVAP' ) then
  setenv OPT 2
  setenv LLL '-24 -21 -18 -15 -12 -9 -6 -3 3 6 9 12 15 18 21 24'
  setenv CCC '33 34 35 36 37 38 39 40 0 41 42 43 44 45 46 47 48'
  setenv UUU 'W m'
  setenv ODR -2
  setenv FAC 1
 else if ( $var == 'NSSR' ) then
  setenv OPT 2
  setenv LLL '-32 -28 -24 -20 -16 -12 -8 -4 4 8 12 16 20 24 28 32'
  setenv CCC '33 34 35 36 37 38 39 40 0 41 42 43 44 45 46 47 48'
  setenv UUU 'W m'
  setenv ODR -2
  setenv FAC 1
 endif

 foreach sea ( sum win )

# season
 if ( $sea == 'sum' ) then
  setenv TSEA 'May to October'
 else if ( $sea == 'win' ) then
  setenv TSEA 'November to April'
 endif

# file copy
 cd $HHH/level_2
 mkdir -p fig/comp/2d_olr
 cd fig/comp/2d_olr
 cp -f $HHH/level_2/sample/comp/gs_2d.sea.with_olr.sample .

 sed "s#homedir#$HHH#g"          gs_2d.sea.with_olr.sample > tmp2
 sed "s/variable/$var/g"                              tmp2 > tmp1
 sed "s/title_var/$TVV/g"                             tmp1 > tmp2
 sed "s/title_mjo/$MJO/g"                             tmp2 > tmp1
 sed "s/season/$sea/g"                                tmp1 > tmp2
 sed "s/title_sea/$TSEA/g"                            tmp2 > tmp1
 sed "s/option/$OPT/g"                                tmp1 > tmp2
 sed "s/levels/$LLL/g"                                tmp2 > tmp1
 sed "s/colors/$CCC/g"                                tmp1 > tmp2
 sed "s/unit1/$UUU/g"                                 tmp2 > tmp1
 sed "s/order1/$ODR/g"                                tmp1 > tmp2
 sed "s/olr_name/$ONM/g"                              tmp2 > tmp1
 sed "s/factor/$FAC/g"                                tmp1 > tmp2
 sed "s/vname/$MJO/g"                                 tmp2 > comp_2d.flux_with_olr.sea.sh

grads -pbc << EOF
comp_2d.flux_with_olr.sea
EOF

 end 
# foreach sea

 end 
# foreach var
